==> compass-domain-0.1.36-sources.jar: com/xforceplus/ultraman/app/compass/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.compass.metadata;

/**
 *
 * @author ultraman
 * @since 2022-05-30
 */

public class PageMeta {
    public interface BillManager {
        static String code() {
            return "billManager";
        }
        static String name() {
            return "账单管理";
        }
    }
    public interface Billnvoice {
        static String code() {
            return "billnvoice";
        }
        static String name() {
            return "账单一级明细";
        }
    }
    public interface Billdetails {
        static String code() {
            return "billdetails";
        }
        static String name() {
            return "账单二级明细";
        }
    }
    public interface BillManagerSupplier {
        static String code() {
            return "billManagerSupplier";
        }
        static String name() {
            return "账单管理销方";
        }
    }
    public interface YearBill {
        static String code() {
            return "yearBill";
        }
        static String name() {
            return "年度账单";
        }
    }
    public interface YearBillMain {
        static String code() {
            return "yearBillMain";
        }
        static String name() {
            return "年度账单主信息";
        }
    }
    public interface YearBillDetail {
        static String code() {
            return "yearBillDetail";
        }
        static String name() {
            return "年度账单明细";
        }
    }
    public interface SalesbillUpload {
        static String code() {
            return "salesbillUpload";
        }
        static String name() {
            return "业务单上传履历";
        }
    }
    public interface MiroResult {
        static String code() {
            return "miroResult";
        }
        static String name() {
            return "MIRO页面";
        }
    }
}

==> compass-domain-0.1.148-sources.jar: com/xforceplus/ultraman/app/compass/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.compass.metadata;

/**
 *
 * @author ultraman
 * @since 2022-09-20
 */

public class PageMeta {
    public interface BillManager {
        static String code() {
            return "billManager";
        }
        static String name() {
            return "账单管理";
        }
    }
    public interface Billnvoice {
        static String code() {
            return "billnvoice";
        }
        static String name() {
            return "账单一级明细";
        }
    }
    public interface Billdetails {
        static String code() {
            return "billdetails";
        }
        static String name() {
            return "账单二级明细";
        }
    }
    public interface BillManagerSupplier {
        static String code() {
            return "billManagerSupplier";
        }
        static String name() {
            return "账单管理销方";
        }
    }
    public interface YearBill {
        static String code() {
            return "yearBill";
        }
        static String name() {
            return "年度账单";
        }
    }
    public interface YearBillMain {
        static String code() {
            return "yearBillMain";
        }
        static String name() {
            return "年度账单主信息";
        }
    }
    public interface YearBillDetail {
        static String code() {
            return "yearBillDetail";
        }
        static String name() {
            return "年度账单明细";
        }
    }
    public interface SalesbillUpload {
        static String code() {
            return "salesbillUpload";
        }
        static String name() {
            return "业务单上传履历";
        }
    }
    public interface MiroResult {
        static String code() {
            return "miroResult";
        }
        static String name() {
            return "MIRO页面";
        }
    }
    public interface NoCoopSalesbill {
        static String code() {
            return "noCoopSalesbill";
        }
        static String name() {
            return "非协同业务单";
        }
    }
    public interface NoCoopSettlement {
        static String code() {
            return "noCoopSettlement";
        }
        static String name() {
            return "非协同结算单";
        }
    }
}
